@@ -32,6 +32,7 @@ class ClickhouseBackend(Backend):
 
     def __init__(self, connection_string: str) -> None:
         self.connection_string = connection_string
+        self._pool = None
 
     def __repr__(self) -> str:
         return f"ClickhouseBackend('{self.connection_string}')"
@@ -73,6 +74,12 @@ class ClickhouseBackend(Backend):
                     await cursor.execute(query=chquery.get_sql(), args=chargs)
                     response = cursor.fetchall()
                 except asynch.errors.ClickHouseException as exc:
+                    logger.debug("ClickHouse exception", exc_info=exc, extra={
+                        "type": "DataQuery",
+                        "query": query,
+                        "sql_query": chquery.get_sql(),
+                        "sql_args": chargs,
+                    })
                     raise UpstreamInternalError(exc.message) from None
 
         return response
@@ -91,6 +98,12 @@ class ClickhouseBackend(Backend):
                     await cursor.execute(query=chquery.get_sql(), args=chargs)
                     response = cursor.fetchall()
                 except asynch.errors.ClickHouseException as exc:
+                    logger.debug("ClickHouse exception", exc_info=exc, extra={
+                        "type": "MembersQuery",
+                        "query": query,
+                        "sql_query": chquery.get_sql(),
+                        "sql_args": chargs,
+                    })
                     raise UpstreamInternalError(exc.message) from None
 
         return response
