@@ -5,7 +5,7 @@ for structs in the requests module.
 """
 
 from dataclasses import dataclass
-from typing import Any, Dict, Iterable
+from typing import Any, Dict, Iterable, Sequence
 
 from tesseract_olap.query.exceptions import EmptyResult
 
@@ -16,7 +16,7 @@ from .requests import DataRequest, MembersRequest
 class DataResult:
     """Container class for results to :class:`DataRequest`."""
     data: Iterable[Dict[str, Any]]
-    sources: Dict[str, str]
+    sources: Sequence[Dict[str, Any]]
     query: DataRequest
 
     def raise_if_empty(self):
