@@ -71,7 +71,9 @@ class OlapServer:
         """
         query = DataQuery.from_request(self.schema, request)
         data = await self.backend.get_data(query, **kwargs)
-        return DataResult(data, query.get_sources(), request)
+        return DataResult(data=data,
+                          sources=query.get_sources(),
+                          query=request)
 
     async def get_members(self, request: MembersRequest, **kwargs) -> MembersResult:
         """Executes a MembersRequest from the user to obtain a list of the
@@ -80,7 +82,8 @@ class OlapServer:
         """
         query = MembersQuery.from_request(self.schema, request)
         data = await self.backend.get_members(query, **kwargs)
-        return MembersResult(data, request)
+        return MembersResult(data=data,
+                             query=request)
 
 
 def _setup_backend(connection: str):
